----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: scalp_scheduler_ack.vhd
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.1
-- Description: Scalp Scheduler Acknowledge.
--
-- Last update: 2019-11-22
--
---------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

--use ieee.std_logic_unsigned.all;
--use ieee.std_logic_arith.all;
use ieee.std_logic_misc.all;

--library UNISIM;
--use UNISIM.VCOMPONENTS.all;

-- use work.utility.all;

entity scalp_scheduler_ack is

    generic (
        C_SCALP_NEIGHBORS_VECTOR_SIZE     : integer range 0 to 255 := 6;
        C_SCALP_SCHEDULER_ACK_VECTOR_SIZE : integer range 0 to 255 := 1);

    port (
        SchedulerAckxDI : in  std_ulogic_vector((C_SCALP_NEIGHBORS_VECTOR_SIZE - 1) downto 0);
        SchedulerAckxDO : out std_ulogic_vector((C_SCALP_SCHEDULER_ACK_VECTOR_SIZE - 1) downto 0));

end entity scalp_scheduler_ack;

architecture dataflow of scalp_scheduler_ack is

    signal InSchedulerAckxD  : std_ulogic_vector((C_SCALP_NEIGHBORS_VECTOR_SIZE - 1) downto 0)     := (others => '0');
    signal OutSchedulerAckxD : std_ulogic_vector((C_SCALP_SCHEDULER_ACK_VECTOR_SIZE - 1) downto 0) := (others => '0');

begin  -- architecture dataflow

    EntityIOxB : block is
    begin  -- block EntityIOxB

        InSchedulerAckxAS  : InSchedulerAckxD <= SchedulerAckxDI;
        OutSchedulerAckxAS : SchedulerAckxDO  <= OutSchedulerAckxD;

    end block EntityIOxB;

    MuxInVectorxB : block is
    begin  -- block MuxInVectorxB

        OrReduceInSchedulerAckxAS : OutSchedulerAckxD(0) <= or_reduce(InSchedulerAckxD);

    end block MuxInVectorxB;

end architecture dataflow;
