----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: scalp_tx_fanout.vhd
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.1
-- Description: Spread of the AXI4 Stream bus.
--
-- Last update: 2020-11-30
--
---------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

--use ieee.std_logic_unsigned.all;
--use ieee.std_logic_arith.all;
--use ieee.std_logic_misc.all;

--library UNISIM;
--use UNISIM.VCOMPONENTS.all;

-- use work.utility.all;
use work.axi4_pkg.all;

entity scalp_tx_fanout is

    generic (
        C_SCALP_NEIGHBORS_VECTOR_SIZE : integer range 0 to 255 := 6);

    port (
        -- RX Side
        RXAxi4M2SLinkxDI : in  t_axi4m2s;
        RXAxi4S2MLinkxDO : out t_axi4s2m;
        -- TX Side
        TXAxi4M2SLinkxDO : out t_axi4m2s_vector((C_SCALP_NEIGHBORS_VECTOR_SIZE - 1) downto 0);
        TXAxi4S2MLinkxDI : in  t_axi4s2m_vector((C_SCALP_NEIGHBORS_VECTOR_SIZE - 1) downto 0));

end entity scalp_tx_fanout;

architecture dataflow of scalp_tx_fanout is

    signal RXAxi4M2SLinkxD : t_axi4m2s                                                      := C_NO_AXI4_M2S;
    signal RXAxi4S2MLinkxD : t_axi4s2m                                                      := C_NO_AXI4_S2M;
    signal TXAxi4M2SLinkxD : t_axi4m2s_vector((C_SCALP_NEIGHBORS_VECTOR_SIZE - 1) downto 0) := (others => C_NO_AXI4_M2S);
    signal TXAxi4S2MLinkxD : t_axi4s2m_vector((C_SCALP_NEIGHBORS_VECTOR_SIZE - 1) downto 0) := (others => C_NO_AXI4_S2M);

begin  -- architecture dataflow

    EntityIOxB : block is
    begin  -- block EntityIOxB

        -- RX Side
        RXAxi4M2SLinkxAS : RXAxi4M2SLinkxD  <= RXAxi4M2SLinkxDI;
        RXAxi4S2MLinkxAS : RXAxi4S2MLinkxDO <= RXAxi4S2MLinkxD;
        -- TX Side
        TXAxi4M2SLinkxAS : TXAxi4M2SLinkxDO <= TXAxi4M2SLinkxD;
        TXAxi4S2MLinkxAS : TXAxi4S2MLinkxD  <= TXAxi4S2MLinkxDI;

    end block EntityIOxB;

    Axi4FanoutxB : block is
    begin  -- block Axi4FanoutxB

        RXAxi4S2MLinkxAS : RXAxi4S2MLinkxD <= or_reduce_t_axi4s2m_vector(TXAxi4S2MLinkxD);

        Axi4M2SFanoutxG : for i in 0 to (C_SCALP_NEIGHBORS_VECTOR_SIZE - 1) generate

            TXAxi4M2SLinkxAS : TXAxi4M2SLinkxD(i) <= RXAxi4M2SLinkxD;

        end generate Axi4M2SFanoutxG;

    end block Axi4FanoutxB;

end architecture dataflow;
